@@ -1,11 +1,7 @@
 package Data::FormValidator::Constraints::Upload;
-
+use Exporter 'import';
 use strict;
 
-require Exporter;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-@ISA = qw(Exporter);
-
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
@@ -14,21 +10,21 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
 
-@EXPORT = qw(
+our @EXPORT = qw(
     valid_file_format
     valid_image_max_dimensions
     valid_file_max_bytes
     valid_image_min_dimensions
 );
 
-@EXPORT_OK = qw(
+our @EXPORT_OK = qw(
     file_format
     image_max_dimensions
     file_max_bytes
     image_min_dimensions
 );
 
-$VERSION = 4.65;
+our $VERSION = 4.81;
 
 sub file_format {
     my %params = @_;
@@ -306,16 +302,12 @@ sub _get_upload_fh
     # we might not have something -seekable-.
     use IO::File;
 
-    # If we we already have an IO::File object, return it, otherwise create one.
-    require Scalar::Util;
-
-    if ( Scalar::Util::blessed($q->{$field}) && $q->{$field}->isa('IO::File') ) {
+    if (ref $q->{$field} eq 'IO::File') {
         return $q->{$field};
     }
     else {
         return IO::File->new_from_fd(fileno($q->{$field}), 'r');
     }
-
 }
 
 ## returns mime type if included as part of the send
@@ -471,7 +463,7 @@ The meta data added is C<width> and C<height>.
 
 An older more awkward interface to the constraints in this module is still supported.
 To use it, you have to load the package with 'validator_packages', and call each
-constraint in a hashref style, passing the the parameters by reference. It looks
+constraint in a hashref style, passing the parameters by reference. It looks
 like this:
 
     validator_packages => [qw(Data::FormValidator::Constraints::Upload)],
